==> 1.5.1.tar.gz: hanoi-towers/hanoi_towers/languages/ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru" sourcelanguage="en">
<context>
    <name>BaseButton</name>
    <message>
        <location filename="../base/BaseButton.qml" line="8"/>
        <source>ok</source>
        <translation>ok</translation>
    </message>
</context>
<context>
    <name>Config</name>
    <message>
        <location filename="../menu/Config.qml" line="28"/>
        <source>Settings</source>
        <translation>Настройки</translation>
    </message>
    <message>
        <location filename="../menu/Config.qml" line="35"/>
        <source>Return to main menu</source>
        <translation>Вернутся в главное меню</translation>
    </message>
    <message>
        <location filename="../menu/Config.qml" line="76"/>
        <source>Standart color</source>
        <translation>Классическая подсветка</translation>
    </message>
    <message>
        <location filename="../menu/Config.qml" line="88"/>
        <source>Random color</source>
        <translation>Разноцветная подсветка</translation>
    </message>
    <message>
        <location filename="../menu/Config.qml" line="99"/>
        <source>Animation</source>
        <translation>Анимация</translation>
    </message>
</context>
<context>
    <name>Header</name>
    <message>
        <location filename="../menu/Header.qml" line="6"/>
        <source></source>
        <translation></translation>
    </message>
    <message>
        <location filename="../menu/Header.qml" line="15"/>
        <source>Main menu</source>
        <translation>Главное меню</translation>
    </message>
</context>
<context>
    <name>Help</name>
    <message>
        <location filename="../Help.qml" line="49"/>
        <source>Your task is to transfer discs of different sizesfrom the left tower to any other free space.You can only transfer the top drive of the tower.You can not transfer several disks at once and put larger disks on small disks.</source>
        <translation>Ваше задание состоит в том, чтобы, перенести диски разных размеров с левой башни в любу другую свободную. Вы можете переносить только верхней диск  башни. Нельзя переносить сразу несколько дисков и ставить большее диски на маленькие.</translation>
    </message>
    <message>
        <location filename="../Help.qml" line="62"/>
        <source>Do not show again:</source>
        <translation>Больше не показвать:</translation>
    </message>
    <message>
        <location filename="../Help.qml" line="90"/>
        <source>Ok</source>
        <translation>Ok</translation>
    </message>
</context>
<context>
    <name>MainMenu</name>
    <message>
        <location filename="../menu/MainMenu.qml" line="21"/>
        <source>Hanoi Towers</source>
        <translation>Ханойские Башни</translation>
    </message>
    <message>
        <location filename="../menu/MainMenu.qml" line="69"/>
        <source>start</source>
        <translation>Начать</translation>
    </message>
    <message>
        <location filename="../menu/MainMenu.qml" line="82"/>
        <source>About</source>
        <translation>об Авторах</translation>
    </message>
    <message>
        <location filename="../menu/MainMenu.qml" line="95"/>
        <source>Config</source>
        <translation>Настройки</translation>
    </message>
    <message>
        <location filename="../menu/MainMenu.qml" line="108"/>
        <source>exit</source>
        <translation>Выход</translation>
    </message>
</context>
<context>
    <name>SwitchLvl</name>
    <message>
        <location filename="../SwitchLvl.qml" line="61"/>
        <source>Start</source>
        <translation>Начать</translation>
    </message>
</context>
<context>
    <name>about</name>
    <message>
        <location filename="../about.qml" line="14"/>
        <source>about</source>
        <translation>Об Авторе</translation>
    </message>
    <message>
        <location filename="../about.qml" line="37"/>
        <source>Product of QuasarApp
* Developers:
* Programmer: Yankovich N. Andrei.
* This game is distributed under the LGPLv3 license.
* Contact: https://github.com/EndrII
* Copyright (C) 2018 Yankovich N. Andrei.</source>
        <translation>Продукт QuasarApp
* Разработчики:
* Программист: Янкович А. Н. 
* Эта игра распостроняеться в соотвецтвии с лицензией LGPLv3.
* Сайт игры: https://quasarapp.github.io/Hanoi-Towers/
* Copyright (C) 2018 Янкович А. Н.</translation>
    </message>
</context>
<context>
    <name>game</name>
    <message>
        <source>Start</source>
        <translation type="vanished">Начать</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation type="vanished">Выход</translation>
    </message>
    <message>
        <source>About</source>
        <translation type="vanished">об Авторах</translation>
    </message>
    <message>
        <location filename="../game.qml" line="80"/>
        <source>lvl </source>
        <translation>Уровень </translation>
    </message>
    <message>
        <location filename="../game.qml" line="104"/>
        <source>step </source>
        <translation>шаг </translation>
    </message>
    <message>
        <location filename="../game.qml" line="69"/>
        <source>Tower height:</source>
        <translation>Высота башни:</translation>
    </message>
    <message>
        <location filename="../game.qml" line="115"/>
        <source>Return to main menu</source>
        <translation>Вернутся в главное меню</translation>
    </message>
    <message>
        <location filename="../game.qml" line="180"/>
        <source>You have passed the level in %0 steps and unlocked level %1
 Minimum steps for this lvl: %2</source>
        <translation>Вы прошли этот уровень за %0 шагов и разблокировали уровень %1
 Минимум шагов на этом уровне: %2</translation>
    </message>
    <message>
        <location filename="../game.qml" line="187"/>
        <source>You have passed the level in %0 steps.
Minimum steps for this lvl: %1</source>
        <translation>Вы прошли этот уровень за %0 шагов
 Минимум шагов на этом уровне: %1</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation type="vanished">Ok</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../main.qml" line="9"/>
        <source>Hanoi Towers</source>
        <translation>Ханойские Башни</translation>
    </message>
</context>
</TS>

==> 1.5.3.tar.gz: hanoi-towers/hanoi_towers/languages/ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru" sourcelanguage="en">
<context>
    <name>BaseButton</name>
    <message>
        <location filename="../base/BaseButton.qml" line="8"/>
        <source>ok</source>
        <translation>ok</translation>
    </message>
</context>
<context>
    <name>Config</name>
    <message>
        <location filename="../menu/Config.qml" line="28"/>
        <source>Settings</source>
        <translation>Настройки</translation>
    </message>
    <message>
        <location filename="../menu/Config.qml" line="35"/>
        <source>Return to main menu</source>
        <translation>Вернутся в главное меню</translation>
    </message>
    <message>
        <location filename="../menu/Config.qml" line="76"/>
        <source>Standart color</source>
        <translation>Классическая подсветка</translation>
    </message>
    <message>
        <location filename="../menu/Config.qml" line="87"/>
        <source>Random color</source>
        <translation>Разноцветная подсветка</translation>
    </message>
    <message>
        <location filename="../menu/Config.qml" line="97"/>
        <source>Animation</source>
        <translation>Анимация</translation>
    </message>
</context>
<context>
    <name>Header</name>
    <message>
        <location filename="../menu/Header.qml" line="6"/>
        <source></source>
        <translation></translation>
    </message>
    <message>
        <location filename="../menu/Header.qml" line="15"/>
        <source>Main menu</source>
        <translation>Главное меню</translation>
    </message>
</context>
<context>
    <name>Help</name>
    <message>
        <source>Your task is to transfer discs of different sizesfrom the left tower to any other free space.You can only transfer the top drive of the tower.You can not transfer several disks at once and put larger disks on small disks.</source>
        <translation type="vanished">Ваше задание состоит в том, чтобы, перенести диски разных размеров с левой башни в любу другую свободную. Вы можете переносить только верхней диск  башни. Нельзя переносить сразу несколько дисков и ставить большее диски на маленькие.</translation>
    </message>
    <message>
        <location filename="../Help.qml" line="49"/>
        <source>Your task is to transfer discs of different sizesfrom the left tower to third tower.You can only transfer the top drive of the tower.You can not transfer several disks at once and put larger disks on small disks.</source>
        <translation>Ваше задание состоит в том, чтобы, перенести диски разных размеров с левой башни в третью башню. Вы можете переносить только верхней диск  башни. Нельзя переносить сразу несколько дисков и ставить большее диски на маленькие.</translation>
    </message>
    <message>
        <location filename="../Help.qml" line="62"/>
        <source>Do not show again:</source>
        <translation>Больше не показвать:</translation>
    </message>
    <message>
        <location filename="../Help.qml" line="90"/>
        <source>Ok</source>
        <translation>Ok</translation>
    </message>
</context>
<context>
    <name>MainMenu</name>
    <message>
        <location filename="../menu/MainMenu.qml" line="21"/>
        <source>Hanoi Towers</source>
        <translation>Ханойские Башни</translation>
    </message>
    <message>
        <location filename="../menu/MainMenu.qml" line="69"/>
        <source>start</source>
        <translation>Начать</translation>
    </message>
    <message>
        <location filename="../menu/MainMenu.qml" line="82"/>
        <source>About</source>
        <translation>об Авторах</translation>
    </message>
    <message>
        <location filename="../menu/MainMenu.qml" line="95"/>
        <source>Config</source>
        <translation>Настройки</translation>
    </message>
    <message>
        <location filename="../menu/MainMenu.qml" line="108"/>
        <source>exit</source>
        <translation>Выход</translation>
    </message>
</context>
<context>
    <name>SwitchLvl</name>
    <message>
        <location filename="../SwitchLvl.qml" line="61"/>
        <source>Start</source>
        <translation>Начать</translation>
    </message>
</context>
<context>
    <name>about</name>
    <message>
        <location filename="../about.qml" line="14"/>
        <source>about</source>
        <translation>Об Авторе</translation>
    </message>
    <message>
        <location filename="../about.qml" line="37"/>
        <source>Product of QuasarApp
* Developers:
* Programmer: Yankovich N. Andrei.
* This game is distributed under the LGPLv3 license.
* Contact: https://github.com/EndrII
* Copyright (C) 2018-2019 Yankovich N. Andrei.</source>
        <translation>Продукт QuasarApp
* Разработчики:
* Программист: Янкович А. Н. 
* Эта игра распостроняеться в соотвецтвии с лицензией LGPLv3.
* Сайт игры: https://quasarapp.github.io/Hanoi-Towers/
* Copyright (C) 2018-2019 Янкович А. Н.</translation>
    </message>
    <message>
        <source>Product of QuasarApp
* Developers:
* Programmer: Yankovich N. Andrei.
* This game is distributed under the LGPLv3 license.
* Contact: https://github.com/EndrII
* Copyright (C) 2018 Yankovich N. Andrei.</source>
        <translation type="vanished">Продукт QuasarApp
* Разработчики:
* Программист: Янкович А. Н. 
* Эта игра распостроняеться в соотвецтвии с лицензией LGPLv3.
* Сайт игры: https://quasarapp.github.io/Hanoi-Towers/
* Copyright (C) 2018 Янкович А. Н.</translation>
    </message>
</context>
<context>
    <name>game</name>
    <message>
        <source>Start</source>
        <translation type="vanished">Начать</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation type="vanished">Выход</translation>
    </message>
    <message>
        <source>About</source>
        <translation type="vanished">об Авторах</translation>
    </message>
    <message>
        <location filename="../game.qml" line="80"/>
        <source>lvl </source>
        <translation>Уровень </translation>
    </message>
    <message>
        <location filename="../game.qml" line="104"/>
        <source>step </source>
        <translation>шаг </translation>
    </message>
    <message>
        <location filename="../game.qml" line="69"/>
        <source>Tower height:</source>
        <translation>Высота башни:</translation>
    </message>
    <message>
        <location filename="../game.qml" line="115"/>
        <source>Return to main menu</source>
        <translation>Вернутся в главное меню</translation>
    </message>
    <message>
        <location filename="../game.qml" line="180"/>
        <source>You have passed the level in %0 steps and unlocked level %1
 Minimum steps for this lvl: %2</source>
        <translation>Вы прошли этот уровень за %0 шагов и разблокировали уровень %1
 Минимум шагов на этом уровне: %2</translation>
    </message>
    <message>
        <location filename="../game.qml" line="187"/>
        <source>You have passed the level in %0 steps.
Minimum steps for this lvl: %1</source>
        <translation>Вы прошли этот уровень за %0 шагов
 Минимум шагов на этом уровне: %1</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation type="vanished">Ok</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../main.qml" line="9"/>
        <source>Hanoi Towers</source>
        <translation>Ханойские Башни</translation>
    </message>
</context>
</TS>
